{ config, pkgs, ... }:

{
  imports =
    [
      ./common.nix
      ./uefi.nix
      ./fstrim.nix
    ];

  environment.etc."lvm/lvm.conf".text = ''
    devices {
      issue_discards = 1
    }
  '';
  boot.initrd.luks.devices = [
    {
      name = "sda2_crypt";
      device = "/dev/disk/by-uuid/663dcfda-081e-40d5-9ba4-62ad73dc5098";
      preLVM = true;
      allowDiscards = true;
    }
  ];

  networking.hostName = "archachatina"; # Define your hostname.
  networking.hostId = "cc7ea3ba";

  environment.systemPackages = with pkgs; [
    beets
    mediainfo
    flac

    recoll
    uvccapture
  ];

  virtualisation.docker.enable = true;
  users.extraUsers.gebner.extraGroups = [ "docker" "libvirtd" ];

  virtualisation.virtualbox.host.enable = true;

  # virtualisation.libvirtd.enable = true;
  networking.firewall.checkReversePath = false;
  # fileSystems."/var/lib/libvirt/images/vaccaria" = {
  #   device = "//vaccaria.mtlaa.gebner.org/export/tmp/vms";
  #   fsType = "cifs";
  #   options = [ "noauto" "x-systemd.automount" "credentials=/etc/smbcredentials/vaccaria"
  #     "forceuid" "forcegid" "uid=0" "gid=0" ];
  # };

  hardware.opengl.driSupport32Bit = true;

  services.nix-serve = {
    enable = true;
    secretKeyFile = "/etc/nix-serve/secret.key";
  };
  networking.firewall.allowedTCPPorts = [ config.services.nix-serve.port ];

  nixpkgs.config.packageOverrides = super: let self = super.pkgs; in {
      # mesa_drivers = self.mesaDarwinOr (
      #   let mo = self.mesa_noglu.override {
      #         llvmPackages = self.llvmPackages_36;
      #       };
      #   in mo.drivers
      # );
  };

}
