{ config, pkgs, ... }:

{
  imports =
    [
      ./common.nix
      ./uefi.nix
      ./fstrim.nix
    ];

  environment.etc."lvm/lvm.conf".text = ''
    devices {
      issue_discards = 1
    }
  '';
  boot.initrd.luks.devices = [
    {
      name = "euhadra_crypt";
      device = "/dev/disk/by-uuid/328a9ede-0958-490b-8e82-62b06b839e21";
      preLVM = true;
      allowDiscards = true;
    }
  ];

  networking.hostName = "euhadra";
  networking.hostId = "ddb5f0fd";

  services.mpd = {
    enable = true;
    musicDirectory = "/mnt/vaccaria/music";
    extraConfig = ''
      audio_output {
        type "alsa"
        name "dac"
        device "sysdefault:CARD=QAMP"
      }

      replaygain "auto"
      restore_paused "yes"
    '';
  };
  networking.firewall.allowedTCPPorts = [ config.services.mpd.network.port ];

  environment.systemPackages = with pkgs; [ mpc_cli ];

  services.xserver.vaapiDrivers = [ pkgs.vaapiIntel ];

  nixpkgs.config.mpv.vaapiSupport = true;

}
