{ config, pkgs, ... }:

{
  imports =
    [
      ./common.nix
      ./uefi.nix
      ./fstrim.nix
    ];

  environment.etc."lvm/lvm.conf".text = ''
    devices {
      issue_discards = 1
    }
  '';
  boot.initrd.luks.devices = [
    {
      name = "sda2_crypt";
      device = "/dev/disk/by-uuid/a7482f34-1d7b-4181-9f3c-f6bbbdb8679d";
      preLVM = true;
      allowDiscards = true;
    }
  ];

  # workaround until trackpad is supported properly
  boot.extraModprobeConfig = ''
    options psmouse proto=imps
  '';

  hardware.trackpoint = {
    enable = true;
    # emulateWheel = true;
  };
  services.xserver.config =
    ''
      Section "InputClass"
        Identifier "Trackpoint Wheel Emulation"
        MatchProduct "PS/2 Synaptics TouchPad"
        MatchDevicePath "/dev/input/event*"
        Option "EmulateWheel" "true"
        Option "EmulateWheelButton" "2"
        Option "Emulate3Buttons" "false"
        Option "XAxisMapping" "6 7"
        Option "YAxisMapping" "4 5"
        EndSection
    '';

  services.tlp.enable = true;

  networking.hostName = "theba"; # Define your hostname.
  networking.hostId = "b29b900f";

  # services.colord.enable = true;

  systemd.services.ModemManager.enable = true;

  hardware.opengl.extraPackages = [ pkgs.vaapiIntel ];

  nixpkgs.config.packageOverrides = pkgs: rec {
  };

  environment.systemPackages = with pkgs; [
    unison
  ];

  virtualisation.docker.enable = true;
  users.extraUsers.gebner.extraGroups = [ "docker" ];

  virtualisation.virtualbox.host.enable = true;

  boot.kernelPackages = pkgs.lib.mkOverride 10 pkgs.linuxPackages;

}
